#!/usr/bin/env python3

import platform
import os

# python -m build creates temporary directories when building the package,
# we can use these temporary directories instead of installing the package
# afterwards. the format of this path is as follows:
# $(pwd)/build/lib.linux-x86_64-cpython-310

cwd = os.getcwd()
system = platform.system().lower()
arch = platform.machine()
impl = platform.python_implementation().lower()
pyver = "".join(map(str, platform.python_version_tuple()[:2]))

print(f"{cwd}/build/lib.{system}-{arch}-{impl}-{pyver}")



# -*- coding: utf-8 -*-
#
import re

from sphinx.domains.python import PyFunction
from sphinx import addnodes

import mesonconf

# project-specific configuration
project = "mididings"
copyright = "mididings contributors"
version = mesonconf.version

# general configuration
extensions = [
    "sphinx.ext.autodoc",
    "sphinxcontrib.fulltoc",
]
root_doc = "index"
exclude_patterns = ["build"]
templates_path = ["templates"]
add_module_names = False

# html configuration
html_theme = "nasophon"
html_theme_path = ["theme"]
html_copy_source = False

# extension configuration - autodoc
autodoc_member_order = "bysource"
autodoc_default_options = {
    "members": True,
    "undoc-members": True,
}


class DingsFunction(PyFunction):
    """
    Stripped-down version of the 'function::' directive that accepts an
    additional argument in angle brackets, used to specify the node's
    'fullname' attribute. This allows proper cross-references to mididings
    operators.
    """

    def handle_signature(self, sig, signode):
        m = re.match("(.*) <([\w.]*)>", sig)
        if m:
            op = m.group(1)
            name = m.group(2)
            modname = self.options.get("module", self.env.temp_data.get("py:module"))

            signode["module"] = modname
            signode["class"] = ""
            signode["fullname"] = name
            signode += addnodes.desc_name(op, op)

            return name, None
        else:
            return super(PyFunction, self).handle_signature(sig, signode)


def setup(app):
    app.add_directive("dingsfun", DingsFunction)



import os
import re

from _mididings import __version__

def open_and_extract(filepath, regex, line_match):
    with open(filepath) as input_file:
        lines = input_file.readlines()

        for line in lines:
            if line.startswith(line_match):
                match = regex.match(line)

                if match:
                    return match.group(1)

class TestVersion:
    def test_versions_match(self):
        version = None
        documentation_version = None
        mididings_version = None

        meson_ver = re.compile(r".*version *: *'([^']*)'")
        doc_ver = re.compile(r"version = (.*)")
        pyproject_dyn_ver = re.compile(r"(dynamic) *= *\[.*'version'.*\]")

        version = open_and_extract("meson.build", meson_ver, "project")
        documentation_version = open_and_extract("doc/conf.py", doc_ver, "version")
        mididings_version = __version__
        pyproject_version = open_and_extract("pyproject.toml", pyproject_dyn_ver, "dynamic")

        assert version is not None
        assert mididings_version is not None
        assert version == mididings_version
        assert documentation_version == "mesonconf.version"
        assert pyproject_version == "dynamic"

